Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateWorktreeName ¶
GenerateWorktreeName uses Claude SDK to generate a unique worktree name To use Haiku model for faster, cost-effective name generation, set:
export ANTHROPIC_MODEL=claude-haiku-4
Types ¶
type Session ¶
type Session struct {
ID string `json:"id"`
Prompt string `json:"prompt"`
Status Status `json:"status"`
OutputFile string `json:"output_file"`
Started time.Time `json:"started"`
AgentID string `json:"agent_id,omitempty"`
WorktreePath string `json:"worktree_path,omitempty"`
WorktreeName string `json:"worktree_name,omitempty"`
BranchName string `json:"branch_name,omitempty"`
}
type WorktreeInfo ¶
type WorktreeInfo struct {
Name string // Generated name for the worktree
Branch string // Git branch name
Path string // Full path to the worktree directory
}
WorktreeInfo contains information about a git worktree for a session
func CreateWorktree ¶
func CreateWorktree(baseDir, branchName, worktreeName string) (*WorktreeInfo, error)
CreateWorktree creates a git worktree with the specified branch
Click to show internal directories.
Click to hide internal directories.